<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="val-ES" sourcelanguage="en">
  <context>
    <name>Gui::Dialog::DlgSettingsOpenSCAD</name>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="14"/>
      <source>General settings</source>
      <translation>Paràmetres generals</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="35"/>
      <source>General OpenSCAD Settings</source>
      <translation>Configuració general de l'OpenSCAD</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="43"/>
      <source>OpenSCAD executable</source>
      <translation>Executable de l'OpenSCAD</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="56"/>
      <source>The path to the OpenSCAD executable</source>
      <translation>El camí a l'executable de l'OpenSCAD</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="74"/>
      <source>OpenSCAD import</source>
      <translation>Importació d'OpenSCAD</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="82"/>
      <source>Print debug information in the Console</source>
      <translation>Mostra informació de depuració a la consola</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="99"/>
      <source>If this is checked, Features will claim their children in the tree view</source>
      <translation>Si està marcada, Funcions mostrarà els seus fills en la vista d'arbre</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="102"/>
      <source>Use ViewProvider in Tree View</source>
      <translation>Utilitza el proveïdor de vistes en la vista d'arbre</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="119"/>
      <source>If this is checked, Multmatrix Object will be Parametric</source>
      <translation>Si està marcada, l'objecte Matriu múltiple serà paramètric</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="122"/>
      <source>Use Multmatrix Feature</source>
      <translation>Utilitza la funcionalitat matriu múltiple</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="139"/>
      <location filename="../ui/openscadprefs-base.ui" line="162"/>
      <source>The maximum number of faces of a polygon, prism or frustum. If fn is greater than this value the object is considered to be a circular. Set to 0 for no limit</source>
      <translation>El nombre màxim de cares d'un polígon, prisma o tronc. Si fn és superior a aquest valor, l'objecte es considera circular. Establiu-ho a 0 per a cap límit</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="142"/>
      <source>Maximum number of faces for polygons (fn)</source>
      <translation>Nombre màxim de cares per a polígons (fn)</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="182"/>
      <source>Send to OpenSCAD via:</source>
      <translation type="unfinished">Send to OpenSCAD via:</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="195"/>
      <source>The transfer mechanism for getting data to and from OpenSCAD</source>
      <translation type="unfinished">The transfer mechanism for getting data to and from OpenSCAD</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="205"/>
      <source>Standard temp directory</source>
      <translation type="unfinished">Standard temp directory</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="210"/>
      <source>User-specified directory</source>
      <translation type="unfinished">User-specified directory</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="215"/>
      <source>stdout pipe (requires OpenSCAD &gt;= 2021.1)</source>
      <translation type="unfinished">stdout pipe (requires OpenSCAD &gt;= 2021.1)</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="227"/>
      <source>Transfer directory</source>
      <translation type="unfinished">Transfer directory</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="240"/>
      <source>The path to the directory for transferring files to and from OpenSCAD</source>
      <translation type="unfinished">The path to the directory for transferring files to and from OpenSCAD</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="258"/>
      <source>OpenSCAD export</source>
      <translation>Exportació a OpenSCAD</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="266"/>
      <source>Maximum fragment size</source>
      <translation type="unfinished">Maximum fragment size</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="289"/>
      <source>angle (fa)</source>
      <translation type="unfinished">angle (fa)</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="385"/>
      <source>Convexity</source>
      <translation type="unfinished">Convexity</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="286"/>
      <location filename="../ui/openscadprefs-base.ui" line="296"/>
      <source>Minimum angle for a fragment</source>
      <translation>Angle mínim d'un fragment</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="328"/>
      <location filename="../ui/openscadprefs-base.ui" line="353"/>
      <source>Minimum size of a fragment</source>
      <translation>Mida mínima d'un fragment</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="331"/>
      <source>size (fs)</source>
      <translation>mida (fs)</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="359"/>
      <source>mm</source>
      <translation>mm</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="422"/>
      <source>Mesh fallback</source>
      <translation>Malla de recolzament</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="442"/>
      <location filename="../ui/openscadprefs-base.ui" line="459"/>
      <source>Deflection</source>
      <translation>Deflexió</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="445"/>
      <source>deflection</source>
      <translation>deflexió</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="452"/>
      <source>Triangulation settings</source>
      <translation>Paràmetres de triangulació</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD</name>
    <message>
      <location filename="../../InitGui.py" line="130"/>
      <source>It looks like you may be using a Snap version of OpenSCAD.</source>
      <translation type="unfinished">It looks like you may be using a Snap version of OpenSCAD.</translation>
    </message>
    <message>
      <location filename="../../InitGui.py" line="135"/>
      <location filename="../../InitGui.py" line="148"/>
      <source>If OpenSCAD execution fails to load the temporary file, use FreeCAD's OpenSCAD Workbench Preferences to change the transfer mechanism.</source>
      <translation type="unfinished">If OpenSCAD execution fails to load the temporary file, use FreeCAD's OpenSCAD Workbench Preferences to change the transfer mechanism.</translation>
    </message>
    <message>
      <location filename="../../InitGui.py" line="143"/>
      <source>It looks like you may be using a sandboxed version of FreeCAD.</source>
      <translation type="unfinished">It looks like you may be using a sandboxed version of FreeCAD.</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="92"/>
      <source>Unable to explode %s</source>
      <translation type="unfinished">Unable to explode %s</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="139"/>
      <source>Convert Edges to Faces</source>
      <translation type="unfinished">Convert Edges to Faces</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="301"/>
      <source>Please select 3 objects first</source>
      <translation type="unfinished">Please select 3 objects first</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="334"/>
      <location filename="../../OpenSCADCommands.py" line="365"/>
      <source>Add</source>
      <translation>Afegir</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="369"/>
      <source>Clear</source>
      <translation>Neteja</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="366"/>
      <source>Load</source>
      <translation type="unfinished">Load</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="367"/>
      <source>Save</source>
      <translation type="unfinished">Save</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="335"/>
      <location filename="../../OpenSCADCommands.py" line="368"/>
      <source>Refresh</source>
      <translation>Actualitza</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="336"/>
      <source>Clear code</source>
      <translation type="unfinished">Clear code</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="337"/>
      <source>Open...</source>
      <translation>Obri...</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="338"/>
      <source>Save...</source>
      <translation type="unfinished">Save...</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="339"/>
      <location filename="../../OpenSCADCommands.py" line="370"/>
      <source>as Mesh</source>
      <translation type="unfinished">as Mesh</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="352"/>
      <location filename="../../OpenSCADCommands.py" line="371"/>
      <source>Add OpenSCAD Element</source>
      <translation type="unfinished">Add OpenSCAD Element</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="428"/>
      <source>Open file</source>
      <translation type="unfinished">Open file</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="430"/>
      <location filename="../../OpenSCADCommands.py" line="444"/>
      <source>OpenSCAD Files</source>
      <translation type="unfinished">OpenSCAD Files</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="442"/>
      <source>Save file</source>
      <translation type="unfinished">Save file</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="456"/>
      <location filename="../../OpenSCADCommands.py" line="485"/>
      <source>Perform</source>
      <translation type="unfinished">Perform</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="482"/>
      <location filename="../../OpenSCADCommands.py" line="486"/>
      <source>Mesh Boolean</source>
      <translation type="unfinished">Mesh Boolean</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="487"/>
      <source>Minkowski sum</source>
      <translation type="unfinished">Minkowski sum</translation>
    </message>
    <message>
      <location filename="../../OpenSCADUtils.py" line="654"/>
      <source>OpenSCAD file contains both 2D and 3D shapes. That is not supported in this importer, all shapes must have the same dimensionality.</source>
      <translation type="unfinished">OpenSCAD file contains both 2D and 3D shapes. That is not supported in this importer, all shapes must have the same dimensionality.</translation>
    </message>
    <message>
      <location filename="../../OpenSCADUtils.py" line="665"/>
      <source>Error: either all shapes must be 2D or all shapes must be 3D</source>
      <translation type="unfinished">Error: either all shapes must be 2D or all shapes must be 3D</translation>
    </message>
    <message>
      <location filename="../../importCSG.py" line="550"/>
      <location filename="../../importCSG.py" line="1432"/>
      <source>Unsupported Function</source>
      <translation type="unfinished">Unsupported Function</translation>
    </message>
    <message>
      <location filename="../../importCSG.py" line="550"/>
      <location filename="../../importCSG.py" line="1432"/>
      <source>Press OK</source>
      <translation>Premeu D'acord</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ExplodeGroup</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="100"/>
      <source>Explode Group</source>
      <translation type="unfinished">Explode Group</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="103"/>
      <source>Remove fusion, apply placement to children, and color randomly</source>
      <translation type="unfinished">Remove fusion, apply placement to children, and color randomly</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ColorCodeShape</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="116"/>
      <source>Color Shapes</source>
      <translation type="unfinished">Color Shapes</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="119"/>
      <source>Color Shapes by validity and type</source>
      <translation type="unfinished">Color Shapes by validity and type</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Edgestofaces</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="136"/>
      <source>Convert Edges To Faces</source>
      <translation type="unfinished">Convert Edges To Faces</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_RefineShapeFeature</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="156"/>
      <source>Refine Shape Feature</source>
      <translation type="unfinished">Refine Shape Feature</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="159"/>
      <source>Create Refine Shape Feature</source>
      <translation type="unfinished">Create Refine Shape Feature</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_MirrorMeshFeature</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="186"/>
      <source>Mirror Mesh Feature...</source>
      <translation type="unfinished">Mirror Mesh Feature...</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="189"/>
      <source>Create Mirror Mesh Feature</source>
      <translation type="unfinished">Create Mirror Mesh Feature</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ScaleMeshFeature</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="215"/>
      <source>Scale Mesh Feature...</source>
      <translation type="unfinished">Scale Mesh Feature...</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="219"/>
      <source>Create Scale Mesh Feature</source>
      <translation type="unfinished">Create Scale Mesh Feature</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ResizeMeshFeature</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="245"/>
      <source>Resize Mesh Feature...</source>
      <translation type="unfinished">Resize Mesh Feature...</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="249"/>
      <source>Create Resize Mesh Feature</source>
      <translation type="unfinished">Create Resize Mesh Feature</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_IncreaseToleranceFeature</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="266"/>
      <source>Increase Tolerance Feature</source>
      <translation type="unfinished">Increase Tolerance Feature</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="269"/>
      <source>Create Feature that allows increasing the tolerance</source>
      <translation type="unfinished">Create Feature that allows increasing the tolerance</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ExpandPlacements</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="283"/>
      <source>Expand Placements</source>
      <translation type="unfinished">Expand Placements</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="286"/>
      <source>Expand all placements downwards in the Tree view</source>
      <translation type="unfinished">Expand all placements downwards in the Tree view</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ReplaceObject</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="304"/>
      <source>Replace Object</source>
      <translation type="unfinished">Replace Object</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="307"/>
      <source>Replace an object in the Tree view. Please select old, new, and parent object</source>
      <translation type="unfinished">Replace an object in the Tree view. Please select old, new, and parent object</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_RemoveSubtree</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="317"/>
      <source>Remove Objects and their Children</source>
      <translation type="unfinished">Remove Objects and their Children</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="320"/>
      <source>Removes the selected objects and all children that are not referenced from other objects</source>
      <translation type="unfinished">Removes the selected objects and all children that are not referenced from other objects</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_AddOpenSCADElement</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="530"/>
      <source>Add OpenSCAD Element...</source>
      <translation type="unfinished">Add OpenSCAD Element...</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="534"/>
      <source>Add an OpenSCAD element by entering OpenSCAD code and executing the OpenSCAD binary</source>
      <translation type="unfinished">Add an OpenSCAD element by entering OpenSCAD code and executing the OpenSCAD binary</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_MeshBoolean</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="545"/>
      <source>Mesh Boolean...</source>
      <translation type="unfinished">Mesh Boolean...</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="549"/>
      <source>Export objects as meshes and use OpenSCAD to perform a boolean operation</source>
      <translation type="unfinished">Export objects as meshes and use OpenSCAD to perform a boolean operation</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Hull</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="566"/>
      <source>Hull</source>
      <translation>Buc/closca</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="569"/>
      <source>Use OpenSCAD to create a hull</source>
      <translation type="unfinished">Use OpenSCAD to create a hull</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../InitGui.py" line="152"/>
      <source>OpenSCAD Tools</source>
      <translation type="unfinished">OpenSCAD Tools</translation>
    </message>
    <message>
      <location filename="../../InitGui.py" line="156"/>
      <source>Frequently-used Part WB tools</source>
      <translation type="unfinished">Frequently-used Part WB tools</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Minkowski</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="586"/>
      <source>Minkowski sum</source>
      <translation type="unfinished">Minkowski sum</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="589"/>
      <source>Use OpenSCAD to create a Minkowski sum</source>
      <translation type="unfinished">Use OpenSCAD to create a Minkowski sum</translation>
    </message>
  </context>
</TS>
